#
# spec file for package sbd
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Lars Marowsky-Bree
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sbd
Summary:        Storage-based death
License:        GPL-2.0+
Group:          Productivity/Clustering/HA
Version:        1.2.1.git.1408100832.f0a4a63
Release:        7.4
Url:            https://github.com/l-mb/sbd
Source:         %{name}-%{version}.tar.xz
Patch1:         add-explicit-libs.patch
Patch2:         sbd-configure-libcoroipcc.patch
Patch3:         sbd-pacemaker.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  glib2-devel
BuildRequires:  libaio-devel
BuildRequires:  libcorosync-devel
BuildRequires:  libglue-devel
BuildRequires:  libpacemaker-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
Conflicts:      ClusterTools2 < 2.3.2
Requires(pre):  %fillup_prereq

%if %{defined systemd_requires}
%systemd_requires
%endif

%description

This package contains the storage-based death functionality.

%prep
###########################################################
# %setup -n sbd-%{version} -q
%setup
%patch1 -p1
%patch2 -p1
%patch3 -p1
###########################################################

%build
autoreconf -i
export CFLAGS="$RPM_OPT_FLAGS -Wall -Werror"
%configure
make %{?_smp_mflags}
###########################################################

%install
###########################################################
make DESTDIR=$RPM_BUILD_ROOT LIBDIR=%{_libdir} install
install -D -m 0755 src/sbd.sh $RPM_BUILD_ROOT/usr/share/sbd/sbd.sh
%if %{defined _unitdir}
install -D -m 0644 src/sbd.service $RPM_BUILD_ROOT/%{_unitdir}/sbd.service
%endif
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates
cp -f src/sbd.sysconfig %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.sbd

%clean
###########################################################
if
  [ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ]
then
  rm -rf $RPM_BUILD_ROOT || true
fi

%if %{defined _unitdir}
%post
%service_add_post sbd.service

if [ ! -e %{_sysconfdir}/sysconfig/sbd ]; then
    %fillup_only sbd
fi

%pre
%service_add_pre sbd.service

%preun
%service_del_preun sbd.service

%postun
%service_del_postun sbd.service
%endif

%files
###########################################################
%defattr(-,root,root)
%{_libdir}/stonith/plugins/external/sbd
%{_sbindir}/sbd
%{_datadir}/sbd
%doc %{_mandir}/man8/sbd*
%if %{defined _unitdir}
%{_unitdir}/sbd.service
%endif
%{_localstatedir}/adm/fillup-templates/sysconfig.sbd
%doc COPYING

%changelog
* Fri Aug 15 2014 lmb@suse.com
- Update to version 1.2.1.git.1408100832.f0a4a63:
  + systemd: Start sbd before corosync instead of pacemaker (bnc#892078)
  + systemd: allow delaying start of post-sbd units (bnc#888935)
- Update _service file.
* Thu Jun 12 2014 lmb@suse.com
- Add _service to pull from latest git.
* Thu Jun  5 2014 lmb@suse.com
- pacemaker: improve XML performance and avoid crash with pacemaker >=
  1.1.12 (bnc#881231)
- man: correct syntax in example for the CIB configuration
- cs: 6f717f5
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu Mar 27 2014 lmb@suse.com
- sbd: Allow the watchdog to be explicitly disabled (bnc#865365)
- rpm: use the short git hash in the changelog from now on.
- cs: b96ac28
* Thu Mar 27 2014 lmb@suse.com
- systemd: ensure that sbd is activated after systemd module loading and
  the iSCSI initator (bnc#869612)
- Start-up: make sbd wait a configurable amount of time for devices to
  appear on boot (bnc#869612)
- Downgrade the logging during the initial wait to a debug log to avoid
  log flooding.
- cs: 512b71dc209744e505bf62d7ccddb70854fe7407
* Thu Oct 10 2013 lmb@suse.com
- systemd support
- /etc/sysconfig/sbd template added
- sbd: Add -p option to specify a pidfile
- sbd-pacemaker: detect whether to run the AIS plugin quorum check at
  runtime
- cs: d7df351e09f903be79495dbe312cf670f1747ef2
* Tue Oct  1 2013 lmb@suse.com
- License update in source files and spec file
- agent: detect if the stonith-timeout is too low (bnc#841010)
- agent: auto-correct pacemaker configuration if a too short timeout is
  detected. This can be disabled using the timeout_bypass option.
  (bnc#841010)
- man: explain why stonith-timeout needs to be larger than msgwait
- Drop fix-check-lib-lib-order.patch: merged upstream
- cs: 3757c4f6bc80146077cb2e019537c44d288f414d
* Fri Sep 13 2013 lmb@suse.com
- Add copyright comment to spec file.
* Tue Jul 30 2013 ygao@suse.com
- Added sbd-pacemaker.patch: Remove use of ais_fd_sync which only exists
  in corosync-1.x-based pacemaker plugin
- Added sbd-configure-libcoroipcc.patch: No longer check libcoroipcc
  when configuring
- Added add-explicit-libs.patch: add explicit libraries to build
  process.
* Thu Jul  4 2013 lmb@suse.com
- sbd-pacemaker: Improve performance
- sbd-pacemaker: handle transient failures of the CIB update processing
- sbd-pacemaker: Log two more cases where pacemaker state could become
  unhealthy
- Bump version number to 1.2.0
- cs: ffca2d93872b81f8b10ef1164c024005576afd4b
* Fri Jun 28 2013 lmb@suse.com
- sbd-pacemaker: update to support build with pacemaker-1.1.10
* Wed May 22 2013 tserong@suse.com
- Fix library link order, add required libraries explicitly
  + fix-check-lib-lib-order.patch
  + add-explicit-libs.patch
* Mon Mar 25 2013 lmb@suse.com
- Introduce -S option to prevent automatic start if the node was
  previously fenced (bnc#812195)
- Reduce number of scenarios where usage help is printed (bnc#812191)
- cs: 1837fd8cc64a
* Wed Feb 27 2013 lmb@suse.com
- Introduce minor header version and add a UUID (bnc#804991)
- Add debug mode level 3 to allow logs to flush, but do actually
  reboot.
- cs: 9641481ebc9b
* Thu Nov 22 2012 lmb@novell.com
- Failure to set watchdog interval is now fatal (bnc#790894)
- cs: d262617db1eb
* Thu Nov 15 2012 lmb@novell.com
- Upstream merge of compatibility changes for pacemaker 1.1.8
- cs: 52ddf89aa96b
* Mon Oct 22 2012 ygao@suse.com
- Changes for being compatible with pacemaker >= 1.1.8
* Fri Sep 28 2012 lmb@novell.com
- Increase sbd's scheduling priority to the maximum (bnc#779259)
- Print proper defaults for -t/-F in sbd help (manpage was already
  correct)
- cs: 6689be9d3aec
* Mon Jun 18 2012 lmb@novell.com
- Remove explicit conflict with cluster-glue.
* Mon Jun 18 2012 lmb@novell.com
- Include a man page for the sbd command.
- Conflict with older versions of ClusterTools2 due to a file
  conflict.
- cs: 3a371cd0f200
* Tue Jun 12 2012 lmb@novell.com
- cs: 68e33d323c6e
- Include more detail on the result of failed async IO in log
- Fix access to unallocated memory in servant
* Wed May 30 2012 lmb@novell.com
- cs: 7d7e0803def7
- Log once if pacemaker state prevented self-fence due to lost device
  majority
- Build using autoconf/autotool
* Tue May 29 2012 lmb@novell.com
- cs: d7c676111472
- Make write IO asynchronous as well.
- Ensure that each mbox will only be zeroed once.
- Initialize sysrq and enable reboot/poweroff flags.
- Unify async IO read/write paths.
* Fri May 25 2012 lmb@novell.com
- Make the code compile on SP1 too, though AIS integration is not
  available there.
* Fri May 25 2012 lmb@novell.com
- cs: dcf1f404b6b7
- Refresh pacemaker state once per second instead of only on CIB update
- Pacemaker state will only be accepted if it is fresh enough
- Refetch the full CIB periodically to notice stalls on notifications
- Request quorum state also from corosync/AIS, not just the CIB
* Thu May 24 2012 lmb@novell.com
- cs: 1cd63d9a962d
- Servants should only be considered live if reporting within
  timeout_io, not timeout_watchdog
- Successful delivery should not be logged at ERROR severity
* Thu May 24 2012 lmb@novell.com
- cs: 01b157f5cfee
- Ensure that sbd latency does not turn negative and thus would cause an
  unnecessary self-fence.
- Drop conflict with older version of cluster-glue; file level conflict
  is sufficient.
* Tue May 22 2012 lmb@novell.com
- cs: 7379080b64ea
- Take pacemaker quorum and node state into account for
  fencing decision (FATE#310625, bnc#767293)
- Adjust sbd servant restart intervals
- Allow setting a different watchdog timeout before crashdump
  (bnc#762300)
- Handle loss of connection to the CIB process properly
- Split sbd off cluster-glue
- Limit number of no restart messages printed (bnc#753559)
- Actually don't restart servants if restart limit reached
- Add debug mode via -Z commandline switch (bnc#753559)
- Fix allocation in the face of failures (bnc#753559)
- handle stuck IO better by explicitly informing our parent
  738295)
- Make servant restart logic more robust and verbose (bnc#738295)
- Make sure the restart limit set to zero works (bnc#738295)
- Use async io for reads (bnc#738295)
- Skip missing/broken devices during list/dump (bnc#761797)
- Add strategic log messages for debuggability
